@@ -17,36 +17,37 @@
 #include "pkg.h"
 #include "bsdstubs.h"
 
-#define PKG_CFLAGS_ONLY_I		(1<<2)
-#define PKG_CFLAGS_ONLY_OTHER		(1<<3)
-#define PKG_CFLAGS			(PKG_CFLAGS_ONLY_I|PKG_CFLAGS_ONLY_OTHER)
-#define PKG_LIBS_ONLY_LDPATH		(1<<5)
-#define PKG_LIBS_ONLY_LIBNAME		(1<<6)
-#define PKG_LIBS_ONLY_OTHER		(1<<7)
-#define PKG_LIBS			(PKG_LIBS_ONLY_LDPATH|PKG_LIBS_ONLY_LIBNAME|PKG_LIBS_ONLY_OTHER)
-#define PKG_MODVERSION			(1<<8)
-#define PKG_REQUIRES			(1<<9)
-#define PKG_REQUIRES_PRIVATE		(1<<10)
-#define PKG_VARIABLES			(1<<11)
-#define PKG_DIGRAPH			(1<<12)
-#define PKG_KEEP_SYSTEM_CFLAGS		(1<<13)
-#define PKG_KEEP_SYSTEM_LIBS		(1<<14)
-#define PKG_VERSION			(1<<15)
-#define PKG_ABOUT			(1<<16)
-#define PKG_ENV_ONLY			(1<<17)
-#define PKG_ERRORS_ON_STDOUT		(1<<18)
-#define PKG_SILENCE_ERRORS		(1<<19)
-#define PKG_IGNORE_CONFLICTS		(1<<20)
-#define PKG_STATIC			(1<<21)
-#define PKG_NO_UNINSTALLED		(1<<22)
-#define PKG_UNINSTALLED			(1<<23)
-#define PKG_LIST			(1<<24)
-#define PKG_HELP			(1<<25)
-#define PKG_PRINT_ERRORS		(1<<26)
-#define PKG_SIMULATE			(1<<27)
-#define PKG_NO_CACHE			(1<<28)
-#define PKG_PROVIDES			(1<<29)
-#define PKG_VALIDATE			(1<<30)
+#define PKG_CFLAGS_ONLY_I		(uint64_t)(1<<2)
+#define PKG_CFLAGS_ONLY_OTHER		(uint64_t)(1<<3)
+#define PKG_CFLAGS			(uint64_t)(PKG_CFLAGS_ONLY_I|PKG_CFLAGS_ONLY_OTHER)
+#define PKG_LIBS_ONLY_LDPATH		(uint64_t)(1<<5)
+#define PKG_LIBS_ONLY_LIBNAME		(uint64_t)(1<<6)
+#define PKG_LIBS_ONLY_OTHER		(uint64_t)(1<<7)
+#define PKG_LIBS			(uint64_t)(PKG_LIBS_ONLY_LDPATH|PKG_LIBS_ONLY_LIBNAME|PKG_LIBS_ONLY_OTHER)
+#define PKG_MODVERSION			(uint64_t)(1<<8)
+#define PKG_REQUIRES			(uint64_t)(1<<9)
+#define PKG_REQUIRES_PRIVATE		(uint64_t)(1<<10)
+#define PKG_VARIABLES			(uint64_t)(1<<11)
+#define PKG_DIGRAPH			(uint64_t)(1<<12)
+#define PKG_KEEP_SYSTEM_CFLAGS		(uint64_t)(1<<13)
+#define PKG_KEEP_SYSTEM_LIBS		(uint64_t)(1<<14)
+#define PKG_VERSION			(uint64_t)(1<<15)
+#define PKG_ABOUT			(uint64_t)(1<<16)
+#define PKG_ENV_ONLY			(uint64_t)(1<<17)
+#define PKG_ERRORS_ON_STDOUT		(uint64_t)(1<<18)
+#define PKG_SILENCE_ERRORS		(uint64_t)(1<<19)
+#define PKG_IGNORE_CONFLICTS		(uint64_t)(1<<20)
+#define PKG_STATIC			(uint64_t)(1<<21)
+#define PKG_NO_UNINSTALLED		(uint64_t)(1<<22)
+#define PKG_UNINSTALLED			(uint64_t)(1<<23)
+#define PKG_LIST			(uint64_t)(1<<24)
+#define PKG_HELP			(uint64_t)(1<<25)
+#define PKG_PRINT_ERRORS		(uint64_t)(1<<26)
+#define PKG_SIMULATE			(uint64_t)(1<<27)
+#define PKG_NO_CACHE			(uint64_t)(1<<28)
+#define PKG_PROVIDES			(uint64_t)(1<<29)
+#define PKG_VALIDATE			(uint64_t)(1<<30)
+#define PKG_LIST_PACKAGE_NAMES		(uint64_t)(1<<31)
 
 static unsigned int global_traverse_flags = PKGF_NONE;
 
@@ -115,6 +116,15 @@ print_list_entry(const pkg_t *entry)
 	printf("%-30s %s - %s\n", entry->id, entry->realname, entry->description);
 }
 
+static void
+print_package_entry(const pkg_t *entry)
+{
+	if (entry->flags & PKG_PROPF_UNINSTALLED)
+		return;
+
+	printf("%s\n", entry->id);
+}
+
 static void
 print_cflags(pkg_list_t *list)
 {
@@ -522,6 +532,7 @@ usage(void)
 	printf("  --errors-to-stdout                print all errors on stdout instead of stderr\n");
 	printf("  --silence-errors                  explicitly be silent about errors\n");
 	printf("  --list-all                        list all known packages\n");
+	printf("  --list-package-names              list all known package names\n");
 	printf("  --simulate                        simulate walking the calculated dependency graph\n");
 	printf("  --no-cache                        do not cache already seen packages when\n");
 	printf("                                    walking the dependency graph\n");
@@ -612,6 +623,7 @@ main(int argc, char *argv[])
 		{ "errors-to-stdout", no_argument, &want_flags, PKG_ERRORS_ON_STDOUT, },
 		{ "silence-errors", no_argument, &want_flags, PKG_SILENCE_ERRORS, },
 		{ "list-all", no_argument, &want_flags, PKG_LIST|PKG_PRINT_ERRORS, },
+		{ "list-package-names", no_argument, &want_flags, PKG_LIST_PACKAGE_NAMES|PKG_PRINT_ERRORS, },
 		{ "simulate", no_argument, &want_flags, PKG_SIMULATE, },
 		{ "no-cache", no_argument, &want_flags, PKG_NO_CACHE, },
 		{ "print-provides", no_argument, &want_flags, PKG_PROVIDES, },
@@ -734,6 +746,12 @@ main(int argc, char *argv[])
 		return EXIT_SUCCESS;
 	}
 
+	if ((want_flags & PKG_LIST_PACKAGE_NAMES) == PKG_LIST_PACKAGE_NAMES)
+	{
+		pkg_scan_all(print_package_entry);
+		return EXIT_SUCCESS;
+	}
+
 	if (required_module_version != NULL)
 	{
 		pkg_t *pkg;
