@@ -19,7 +19,7 @@
 #ifdef _WIN32
 #	define PKG_CONFIG_REG_KEY "Software\\pkgconfig\\PKG_CONFIG_PATH"
 #	undef PKG_DEFAULT_PATH
-#	define PKG_DEFAULT_PATH "../lib/pkgconfig:../share/pkgconfig"
+#	define PKG_DEFAULT_PATH "../lib/pkgconfig;../share/pkgconfig"
 #endif
 
 #define PKG_CONFIG_EXT		".pc"
@@ -116,19 +116,24 @@ get_pkgconfig_path(void)
 		return env_path;
 
 #ifdef _WIN32
-	GetModuleFileName(NULL, namebuf, sizeof namebuf);
-
-	p = strrchr(namebuf, '\\');
-	if (p == NULL)
-		p = strrchr(namebuf, '/');
+	int sizepath = GetModuleFileName(NULL, namebuf, sizeof namebuf);
+	char * winslash;
+	namebuf[sizepath] = '\0';
+	while ((winslash = strchr (namebuf, '\\')) != NULL)
+	{
+		*winslash = '/';
+	}
+	p = strrchr(namebuf, '/');
 	if (p == NULL)
 		return PKG_DEFAULT_PATH;
 
 	*p = '\0';
 	strlcpy(outbuf, namebuf, sizeof outbuf);
+	strlcat(outbuf, "/", sizeof outbuf);
 	strlcat(outbuf, "../lib/pkgconfig", sizeof outbuf);
-	strlcat(outbuf, ":", sizeof outbuf);
+	strlcat(outbuf, ";", sizeof outbuf);
 	strlcat(outbuf, namebuf, sizeof outbuf);
+	strlcat(outbuf, "/", sizeof outbuf);
 	strlcat(outbuf, "../share/pkgconfig", sizeof outbuf);
 
 	return outbuf;
@@ -212,8 +217,6 @@ pkg_new_from_file(const char *filename, FILE *f, unsigned int flags)
 	{
 		char op, *p, *key, *value;
 
-		readbuf[strlen(readbuf) - 1] = '\0';
-
 		p = readbuf;
 		while (*p && (isalpha(*p) || isdigit(*p) || *p == '_' || *p == '.'))
 			p++;
@@ -247,13 +250,13 @@ pkg_new_from_file(const char *filename, FILE *f, unsigned int flags)
 			else if (!strcmp(key, "Version"))
 				pkg->version = pkg_tuple_parse(&pkg->vars, value);
 			else if (!strcasecmp(key, "CFLAGS"))
-				pkg_fragment_parse(&pkg->cflags, &pkg->vars, value);
+				pkg_fragment_parse(&pkg->cflags, &pkg->vars, value, flags);
 			else if (!strcasecmp(key, "CFLAGS.private"))
-				pkg_fragment_parse(&pkg->cflags_private, &pkg->vars, value);
+				pkg_fragment_parse(&pkg->cflags_private, &pkg->vars, value, flags);
 			else if (!strcasecmp(key, "LIBS"))
-				pkg_fragment_parse(&pkg->libs, &pkg->vars, value);
+				pkg_fragment_parse(&pkg->libs, &pkg->vars, value, flags);
 			else if (!strcasecmp(key, "LIBS.private"))
-				pkg_fragment_parse(&pkg->libs_private, &pkg->vars, value);
+				pkg_fragment_parse(&pkg->libs_private, &pkg->vars, value, flags);
 			else if (!strcmp(key, "Requires"))
 				pkg_dependency_parse(pkg, &pkg->requires, value);
 			else if (!strcmp(key, "Requires.private"))
@@ -262,18 +265,7 @@ pkg_new_from_file(const char *filename, FILE *f, unsigned int flags)
 				pkg_dependency_parse(pkg, &pkg->conflicts, value);
 			break;
 		case '=':
-			if (!(flags & PKGF_MUNGE_SYSROOT_PREFIX) || strcasecmp(key, "prefix"))
-				pkg_tuple_add(&pkg->vars, key, value);
-			else
-			{
-				char mungebuf[PKG_BUFSIZE];
-				char *sysroot_dir = pkg_tuple_find_global("pc_sysrootdir");
-
-				strlcpy(mungebuf, sysroot_dir, sizeof mungebuf);
-				strlcat(mungebuf, value, sizeof mungebuf);
-
-				pkg_tuple_add(&pkg->vars, key, mungebuf);
-			}
+			pkg_tuple_add(&pkg->vars, key, value);
 			break;
 		default:
 			break;
@@ -980,7 +972,7 @@ pkg_traverse(pkg_t *root,
 
 	if (flags & PKGF_SEARCH_PRIVATE)
 	{
-		eflags = pkg_walk_list(root, &root->requires_private, func, data, maxdepth, rflags);
+		eflags = pkg_walk_list(root, &root->requires_private, func, data, maxdepth, rflags | PKGF_ITER_PKG_IS_PRIVATE);
 		if (eflags != PKG_ERRF_OK)
 			return eflags;
 	}
@@ -998,8 +990,7 @@ pkg_cflags_collect(pkg_t *pkg, void *data, unsigned int flags)
 	PKG_FOREACH_LIST_ENTRY(pkg->cflags.head, node)
 	{
 		pkg_fragment_t *frag = node->data;
-
-		pkg_fragment_copy(list, frag, flags);
+		pkg_fragment_copy(list, frag, flags, false);
 	}
 }
 
@@ -1014,7 +1005,7 @@ pkg_cflags_private_collect(pkg_t *pkg, void *data, unsigned int flags)
 	{
 		pkg_fragment_t *frag = node->data;
 
-		pkg_fragment_copy(list, frag, flags);
+		pkg_fragment_copy(list, frag, flags, true);
 	}
 }
 
@@ -1047,23 +1038,16 @@ pkg_libs_collect(pkg_t *pkg, void *data, unsigned int flags)
 	PKG_FOREACH_LIST_ENTRY(pkg->libs.head, node)
 	{
 		pkg_fragment_t *frag = node->data;
-
-		pkg_fragment_copy(list, frag, flags);
+		pkg_fragment_copy(list, frag, flags, (flags & PKGF_ITER_PKG_IS_PRIVATE) != 0);
 	}
-}
 
-static void
-pkg_libs_private_collect(pkg_t *pkg, void *data, unsigned int flags)
-{
-	pkg_list_t *list = data;
-	pkg_node_t *node;
-	(void) flags;
-
-	PKG_FOREACH_LIST_ENTRY(pkg->libs_private.head, node)
+	if (flags & PKGF_MERGE_PRIVATE_FRAGMENTS)
 	{
-		pkg_fragment_t *frag = node->data;
-
-		pkg_fragment_copy(list, frag, flags);
+		PKG_FOREACH_LIST_ENTRY(pkg->libs_private.head, node)
+		{
+			pkg_fragment_t *frag = node->data;
+			pkg_fragment_copy(list, frag, flags, true);
+		}
 	}
 }
 
@@ -1080,12 +1064,5 @@ pkg_libs(pkg_t *root, pkg_list_t *list, int maxdepth, unsigned int flags)
 		return eflag;
 	}
 
-	if (flags & PKGF_MERGE_PRIVATE_FRAGMENTS)
-	{
-		eflag = pkg_traverse(root, pkg_libs_private_collect, list, maxdepth, flags);
-		if (eflag != PKG_ERRF_OK)
-			pkg_fragment_free(list);
-	}
-
 	return eflag;
 }
